Display a spatial interaction function.
Arguments
- fun
spatial interaction function. Options are "p" (pareto, power law) or "e" (exponential). For pareto the interaction is defined as: (1 + alpha * mDistance) ^ (-beta). For "exponential" the interaction is defined as: exp(- alpha * mDistance ^ beta). The alpha parameter is computed from parameters given by the user (
betaandspan).- span
distance where the density of probability of the spatial interaction function equals 0.5.
- beta
impedance factor for the spatial interaction function.
- limit
maximum distance used to retrieved
xpoints, in map units.